==> rubbrband-0.1.31-py3-none-any.whl: rubbrband/clients/docker_client.py <==
import docker
import typer
from rich.progress import Progress

tasks = {}

try:
    DOCKER_CLIENT = docker.from_env()
except docker.errors.DockerException:
    typer.echo("Docker is not running as root. Please start Docker or run sudo su root.")
    exit()


# Show task progress (red for download, green for extract)
def show_progress(line, progress):
    if line["status"] == "Downloading":
        id = f'[red][Download {line["id"]}]'
    elif line["status"] == "Extracting":
        id = f'[green][Extract  {line["id"]}]'
    else:
        # skip other statuses
        return

    if id not in tasks.keys():
        tasks[id] = progress.add_task(f"{id}", total=line["progressDetail"]["total"])
    else:
        progress.update(tasks[id], completed=line["progressDetail"]["current"])


def pull_image(image_name):
    with Progress() as progress:
        resp = DOCKER_CLIENT.api.pull(image_name, stream=True, decode=True)
        for line in resp:
            show_progress(line, progress)


def pull_image_handler(image_name):
    """Pulls an image from the registry if it is not found locally or if the local image is outdated."""

    matched_images = DOCKER_CLIENT.images.list(image_name)
    registry_digest_sha = DOCKER_CLIENT.images.get_registry_data(image_name).attrs["Descriptor"]["digest"]

    if len(matched_images) == 0:
        typer.echo("Model not found locally, downloading model.")
        pull_image(image_name)
    elif matched_images[0].attrs["RepoDigests"][0].split("@")[1] != registry_digest_sha:
        typer.echo("Model found locally, but is outdated. Downloading new model.")
        pull_image(image_name)
    else:
        typer.echo("Model found locally, skipping download.")


def get_container(container_name):
    """Returns a container object if it exists and is running."""
    try:
        container = DOCKER_CLIENT.containers.get(container_name)
    except docker.errors.NotFound:
        typer.echo("Model not found, try running rubbrband launch <model>")
        return

    if container.status != "running":
        typer.echo("Model is not running, attemping to start model.")
        try:
            container.start()
        except docker.errors.APIError:
            typer.echo("Unable to start model. Please try again.")
            return

    return container

==> rubbrband-0.1.36-py3-none-any.whl: rubbrband/clients/docker_client.py <==
import docker
import typer
from rich.progress import Progress

tasks = {}

try:
    DOCKER_CLIENT = docker.from_env()
except docker.errors.DockerException:
    typer.echo("Docker is not running as root. Please start Docker or run sudo su root.")
    exit()


# Show task progress (red for download, green for extract)
def show_progress(line, progress):
    if line["status"] == "Downloading":
        id = f'[red][Download {line["id"]}]'
    elif line["status"] == "Extracting":
        id = f'[green][Extract  {line["id"]}]'
    else:
        # skip other statuses
        return

    if id not in tasks.keys():
        tasks[id] = progress.add_task(f"{id}", total=line["progressDetail"]["total"])
    else:
        progress.update(tasks[id], completed=line["progressDetail"]["current"])


def pull_image(image_name):
    with Progress() as progress:
        resp = DOCKER_CLIENT.api.pull(image_name, stream=True, decode=True)
        for line in resp:
            show_progress(line, progress)


def pull_image_handler(image_name):
    """Pulls an image from the registry if it is not found locally or if the local image is outdated."""

    matched_images = DOCKER_CLIENT.images.list(image_name)
    registry_digest_sha = DOCKER_CLIENT.images.get_registry_data(image_name).attrs["Descriptor"]["digest"]

    try:
        local_digest_sha = matched_images[0].attrs["RepoDigests"][0].split("@")[1]
    except IndexError:
        local_digest_sha = None

    if len(matched_images) == 0:
        typer.echo("Model not found locally, downloading model.")
        pull_image(image_name)
    elif local_digest_sha != registry_digest_sha:
        typer.echo("Model found locally, but is outdated. Downloading new model.")
        pull_image(image_name)
    else:
        typer.echo("Model found locally, skipping download.")


def get_container(container_name):
    """Returns a container object if it exists and is running."""
    try:
        container = DOCKER_CLIENT.containers.get(container_name)
    except docker.errors.NotFound:
        typer.echo("Model not found, try running rubbrband launch <model>")
        return

    if container.status != "running":
        typer.echo("Model is not running, attemping to start model.")
        try:
            container.start()
        except docker.errors.APIError:
            typer.echo("Unable to start model. Please try again.")
            return

    return container
